pub struct DeviceInfo {
pub name: Option<String>,
pub description: Option<String>,
pub model_family: Option<String>,
pub hardware_version: Option<String>,
pub software_version: Option<String>,
pub owners: Vec<String>,
}Expand description
Neutral device metadata the bridge syncs with the remote. The bridge-flavored
wire form (studio-bridge’s PartialDeviceInfo) is converted to/from this by
the connector.
Fields
name: Option<String>description: Option<String>model_family: Option<String>hardware_version: Option<String>software_version: Option<String>owners: Vec<String>Trait Implementations
Sourceimpl Clone for DeviceInfo
impl Clone for DeviceInfo
Sourcefn clone(&self) -> DeviceInfo
fn clone(&self) -> DeviceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceInfo
impl Debug for DeviceInfo
Sourceimpl Default for DeviceInfo
impl Default for DeviceInfo
Sourcefn default() -> DeviceInfo
fn default() -> DeviceInfo
Returns the “default value” for a type. Read more
impl Eq for DeviceInfo
Sourceimpl PartialEq for DeviceInfo
impl PartialEq for DeviceInfo
Sourcefn eq(&self, other: &DeviceInfo) -> bool
fn eq(&self, other: &DeviceInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for DeviceInfo